+++
title = "Multi-line footnote"
tags = ["footnote"]
draft = false
+++

This is some text[^fn:1].

[^fn:1]: This is a long footnote. It is so long that it gets auto-filled over multiple lines. But even then it should be handled fine.
